@@ -109,7 +109,7 @@ QDomElement BasePluginContainer::loadSettings(const QDomElement source)
 	{
 		QString pluginName;
 		NXml::getAttribute(singlePluginElement, pluginName, "name", "");
-		qDebug("Loaded <SinglePlugin name=\"" + pluginName + "\"> settings");
+// 		qStrDebug("Loaded <SinglePlugin name=\"" + pluginName + "\"> settings");
 		if (_plugins.find(toString(pluginName)) != _plugins.end())
 		{
 			Plugin* pPlugin = _plugins[toString(pluginName)];
@@ -117,11 +117,10 @@ QDomElement BasePluginContainer::loadSettings(const QDomElement source)
 		}
 		else
 		{
-			qDebug("Warning: found unknown <SinglePlugin name=\"" + pluginName + "\"> settings");
+			qStrWarning("found unknown <SinglePlugin name=\"" + pluginName + "\"> settings entry");
 		}
 		singlePluginElement = NXml::getNextElement(singlePluginElement);
 	}
-	qDebug("Source.tagName: "+source.tagName());
 	return NXml::getNextElement(source);
 }
 
@@ -149,7 +148,7 @@ QDomElement BasePluginContainer::loadContainerSettings(const QDomElement source)
 	return source;
 }
 
-void BasePluginContainer::saveContainerSettings(NXml::XmlData& outData, QDomElement parent) const
+void BasePluginContainer::saveContainerSettings(NXml::XmlData&, QDomElement) const
 {
 }
 
