@@ -29,8 +29,8 @@ public:
 
 	~ColumnControlDlg();
 	void setContent(const QStringList & shown, const QStringList & hidden);
-	QStringList getShown();
-	QStringList getHidden();
+	QStringList shownColumns();
+	QStringList hiddenColumns();
 protected slots:
 	void on__pHideButton_clicked();
 	void on__pShowButton_clicked();
