@@ -14,6 +14,7 @@
 
 #include <iostream>
 #include <algorithm>
+#include <functional>
 #include <cassert>
 
 
@@ -31,6 +32,7 @@
 #include <QStringList>
 #include <qtabwidget.h>
 #include <QTime>
+#include <QTimer>
 #include <QToolBar>
 #include <QWhatsThis>
 #include <QtDebug>
@@ -58,6 +60,7 @@
 #include "pluginmanager.h"
 #include "packagenotfoundexception.h"
 #include "plugincompare.h"
+#include "pluginsettingsdlg.h"
 #include "packagenameplugin.h"
 #include "scoredisplayplugin.h"
 
@@ -98,6 +101,7 @@ PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFl
 	setupUi(this);
  	delete _pPackageView;
 	_pPackageView = new NPackageSearch::PackageDisplayWidget(_pPackageViewFrame);
+	_pPackageView->setWhatsThis("Displays the packages matching the search entered above.");
  	_pPackageViewFrame->layout()->addWidget(_pPackageView);
 	// former ui.h initialization
 	init();
@@ -129,12 +133,14 @@ PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFl
     connect(helpContentsAction, SIGNAL(triggered()), SLOT(onHelpContentsAction()));
     connect(_pBackButton, SIGNAL(clicked()), SLOT(onBack()));
     connect(_pForwardButton, SIGNAL(clicked()), SLOT(onForward()));
-    connect(_pFileExitAction, SIGNAL(triggered()), SLOT(close()));
+    connect(_pExitAction, SIGNAL(triggered()), SLOT(close()));
     connect(_pDetailsView, SIGNAL(sourceChanged(const QUrl&)), SLOT(onLinkClicked(const QUrl&)));
     connect(_pInformationContainer, SIGNAL(currentChanged(int)), SLOT(onInformationPageChanged()));
     connect(_pControlPluginsAction, SIGNAL(triggered()), SLOT(onControlPlugins()));
-    connect(_pPluginSettingsAction, SIGNAL(triggered()), SLOT(onPluginSettings()));
+    connect(_pPreferencesAction, SIGNAL(triggered()), SLOT(onPreferences()));
     connect(_pPackageSelection, SIGNAL(activated(const QString&)), SLOT(selectNewPackage(const QString&)));
+    connect(&timer, SIGNAL(timeout()), SLOT(checkAptDbForUpdates()));
+    timer.start(2000);
 }
 
 PackageSearchImpl::~PackageSearchImpl()
@@ -216,17 +222,11 @@ void PackageSearchImpl::initToolbars()
 void PackageSearchImpl::initMenus()
 {
 	_pHelpMenu->insertAction(helpContentsAction, _pWhatsThisAction);
-	
-	QMenu* pViewMenu = new QMenu(tr("View"), _pMenuBar);
-	_pMenuBar->insertMenu(_pSystemMenu->menuAction(), pViewMenu);
-	pViewMenu->addAction(_pMainToolBar->toggleViewAction());
+	_pViewMenu->addAction(_pMainToolBar->toggleViewAction());
 
-	QMenu* pPackageMenu = new QMenu(tr("Packages"), _pMenuBar);
-	_pMenuBar->insertMenu(_pSystemMenu->menuAction(), pPackageMenu);
-
-	_nameToMenu["File"] = _pFileMenu;
-	_nameToMenu["View"] = pViewMenu;
-	_nameToMenu["Packages"] = pPackageMenu;
+	_nameToMenu["Packagesearch"] = _pPackagesearchMenu;
+	_nameToMenu["View"] = _pViewMenu;
+	_nameToMenu["Packages"] = _pPackagesMenu;
 	_nameToMenu["System"] = _pSystemMenu;
 	_nameToMenu["Plugins"] = _pPluginsMenu;
 	_nameToMenu["Help"] = _pHelpMenu;
@@ -451,11 +451,11 @@ const set<string>& PackageSearchImpl::packages() const
 
 void PackageSearchImpl::reloadAptFrontCache()
 {
-	delete _pDebtags;
+// 	delete _pDebtags;
 	delete _pApt;
 	delete _pTextsearch;
+// 	_pDebtags = new ept::debtags::Debtags;
 	_pApt = new ept::apt::Apt;
-	_pDebtags = new ept::debtags::Debtags;
 	_pTextsearch = new ept::textsearch::TextSearch;
 }
 
@@ -544,30 +544,6 @@ void PackageSearchImpl::removePlugin(NPlugin::Plugin* pPlugin)
 void PackageSearchImpl::addShortInformationPlugin(NPlugin::ShortInformationPlugin* pPlugin)
 {
 	_shortInformationPlugins.insert(pPlugin);
-	// if the column is not already in the list, add it before the first column
-	// with a higher priority value
-/*	if (!_pPackageListViewControl->isExisting(pPlugin->shortInformationCaption()))
-	{
-		QStringList columns = _pPackageListViewControl->shownColumns();
-		int position = 0;
-		int priority = pPlugin->shortInformationPriority();
-		// find the position for the first plugin with a higher priority value
-		for (QStringList::const_iterator it = columns.begin(); it != columns.end(); ++it)
-		{
-			NPlugin::ShortInformationPlugin* p = getShortInformationPluginWithCaption(*it);
-			if (p && p->shortInformationPriority() > priority)
-			{
-				break;
-			}
-			++position;
-		}
-		_pPackageListViewControl->addColumn
-		(
-			pPlugin->shortInformationCaption(), 
-			position,
-			(pPlugin->preferredColumnWidth()==-1) ? -1 : pPlugin->preferredColumnWidth() * CHAR_WIDTH + MARGIN
-		);
-	}*/
 }
 
 void PackageSearchImpl::addActionPlugin(NPlugin::ActionPlugin* pPlugin)
@@ -586,10 +562,9 @@ void PackageSearchImpl::addActionPlugin(NPlugin::ActionPlugin* pPlugin)
 			}
 			else
 			{
-				QString debugMessage = "Requested to add to an unknown menu \"" 
-					+ pAction->menu() + "\" in plugin " + pPlugin->name() + ".\n"
-					+ "Added to system menu instead.";
-				qDebug(debugMessage.toAscii());
+				qWarning() << "Requested to add to an unknown menu \"" <<  pAction->menu() 
+					<< "\" in plugin " << pPlugin->name() << ".\n"
+					<< "Added to system menu instead.";
 				pMenu = _pSystemMenu;
 			}
 			pMenu->addAction(pAction->action());
@@ -604,10 +579,9 @@ void PackageSearchImpl::addActionPlugin(NPlugin::ActionPlugin* pPlugin)
 			}
 			else
 			{
-				QString debugMessage = "Requested to add to an unknown toolbar \""
-					+ pAction->toolBar() + "\" in plugin " + pPlugin->name() + "\n"
-					+ "Added to main toolbar instead.";
-				qDebug(debugMessage.toAscii());
+				qWarning() << "Requested to add to an unknown toolbar \""
+					<< pAction->toolBar() << "\" in plugin " << pPlugin->name() << "\n"
+					<< "Added to main toolbar instead.";
 				pToolBar = _pMainToolBar;
 			}
 			pToolBar->addAction(pAction->action());
@@ -913,15 +887,20 @@ void PackageSearchImpl::onControlPlugins()
 	_pPluginManager->showControlDialog(this);
 }
 
-void PackageSearchImpl::onPluginSettings()
+void PackageSearchImpl::onPreferences()
 {
-	_pPluginManager->showSettingsDialog(this);
+	NPlugin::PluginSettingsDlg dlg(this);
+	vector<NPlugin::PluginContainer*> plugins = _pPluginManager->getLoadedPlugins();
+	for_each(plugins.begin(), plugins.end(), 
+			bind1st( mem_fun(&NPlugin::PluginSettingsDlg::addPlugin), &dlg) );
+	if ( dlg.exec() == QDialog::Accepted )
+		for_each( plugins.begin(), plugins.end(),
+				mem_fun(&NPlugin::PluginContainer::applySettings) );
 }
 
 
 void PackageSearchImpl::closeEvent(QCloseEvent* pE)
 {
-	qDebug("closing");
 	saveSettings();
 	pE->accept();
 }
@@ -1026,5 +1005,11 @@ void PackageSearchImpl::setPackageActionsEnabled(bool enabled)
 		(*it)->setEnabled(enabled);
 }
 
+void PackageSearchImpl::checkAptDbForUpdates()
+{
+	_pApt->checkCacheUpdates();
+}
+
+
 
 
