@@ -17,6 +17,8 @@
 #include <vector>
 #include <map>
 
+#include <QTimer>
+
 #include "ui_packagesearch.h"
 
 // NPlugin
@@ -140,6 +142,13 @@ public:
 public slots:
 	/** Call this function after the dialog is shown to initialize the whole system. */
 	void initialize();
+	
+	/** @brief This method checks, if the apt-cache has changed and if neccessary reloads
+	  * the apt database. 
+	  *
+	  * Currently it is periodically called by a timer.
+	  */
+	void checkAptDbForUpdates();
 protected slots:
 	/** @brief This let the views show all information available about the package.
 	  *
@@ -161,8 +170,8 @@ protected slots:
 	/** This shows the control dialog for the plugins. */
 	virtual void onControlPlugins();
 	
-	/** This shows a settings dialog for the plugins. */
-	virtual void onPluginSettings();
+	/** This shows a settings dialog. */
+	virtual void onPreferences();
 	virtual void saveSettings();
 	virtual void loadSettings();
 	
@@ -325,6 +334,8 @@ private:
 	NPlugin::Plugin* _pPackageNamePlugin;
 	/** @brief This plugin is used to display and calculate the scores for the packages. */
 	NPlugin::ScoreDisplayPlugin* _pScoreDisplayPlugin;
+	/** @brief Timer used to periodically call checkAptDbForUpdates(). */
+	QTimer timer;
 };
 
 #endif // __PACKAGESEARCHIMPL_H_2004_03_21
