@@ -201,6 +201,3 @@ QString AptFrontPackage::getRelation(Relation::Type type) const
 
 }
 
-#undef emit
-//#include <ept/cache/apt/packages.tcc>
-//#include <ept/cache/relation.tcc>
