@@ -19,6 +19,7 @@
 #include <QStringList>
 
 // NPlugin
+#include <iprogressobserver.h>
 #include <iprovider.h>
 #include <packagenotfoundexception.h>
 
@@ -66,20 +67,13 @@ IPackage::InstalledState AptFrontPackageDB::getState(const string& package) cons
 	return getPackageRecord(package).installedState();
 }
 
-void AptFrontPackageDB::reloadPackageInformation(NUtil::IProgressObserver*)
+void AptFrontPackageDB::reloadPackageInformation(NUtil::IProgressObserver* pObserver)
 {
 	_pProvider->reloadAptFrontCache();
+	if (pObserver)
+		pObserver->setProgress(100);
 }
 
-int AptFrontPackageDB::getDescriptionCount(const string& package, const QString& pattern, bool caseSensitive) const
-{
-	return 1;
-}
-bool AptFrontPackageDB::matchesName(const string& package, const QString& pattern, bool caseSensitive) const
-{
-}
-
-
 
 /////////////////////////////////////////////////////
 // IAptSearch Interface
@@ -92,11 +86,15 @@ bool AptFrontPackageDB::search(std::set<string>& result,
 	typedef ept::textsearch::TextSearch TextSearch;
 	Qt::CaseSensitivity qCaseSensitive = caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive;
 	const Apt& packages = _pProvider->apt();
-	const TextSearch& textsearch = _pProvider->textsearch();
 	if (searchDescr)
 	{
+// don't compile xapian search
+#if 0
+		// Check also for index being up to date
 		if (textsearch.hasData())
 		{
+			
+			const TextSearch& textsearch = _pProvider->textsearch();
 			Xapian::Enquire enq(textsearch.db());
 			enq.set_query( textsearch.makeORQuery(toString(pattern)) );
 // 			textsearch.search(enq, pattern.ascii());
@@ -111,7 +109,10 @@ bool AptFrontPackageDB::search(std::set<string>& result,
 				// For reference, this would be the Xapian relevance
 				// i.get_percent();
 			}
-		} else {
+		} 
+		else 
+#endif
+		{
 			ept::apt::PackageRecord rec;
 			for ( Apt::record_iterator it = packages.recordBegin(); it != packages.recordEnd(); ++it )
 			{
@@ -140,14 +141,24 @@ bool AptFrontPackageDB::search(std::set<string>& result, const QStringList& incl
 	typedef ept::textsearch::TextSearch TextSearch;
 	Qt::CaseSensitivity qCaseSensitive = caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive;
 	const Apt& packages = _pProvider->apt();
-	const TextSearch& textsearch = _pProvider->textsearch();
 	if (searchDescr)
 	{
 		ept::apt::PackageRecord rec;
-		if (textsearch.hasData())
+// don't compile xapian search
+#if 0
+		const TextSearch& textsearch = _pProvider->textsearch();
+		bool useXapian = false;
+		// currently do not use Xapian
+		if (false) 
+		{
+			useXapian = textsearch.hasData();
+			// todo: set useXapian to false if the index is outdated (textsearch.timestamp())
+			// or if the search is not whole words only
+		}
+		if (useXapian)
 		{
 			//try {
-			Xapian::Enquire enq(textsearch.db());
+			Xapian::Enquire enq(textsearch.db(0, 50));
 			vector<string> patterns;
 			// Get the weighted OR include query
 			for (QStringList::const_iterator jt = includePatterns.begin(); jt != includePatterns.end(); ++jt)
@@ -168,7 +179,7 @@ bool AptFrontPackageDB::search(std::set<string>& result, const QStringList& incl
 			}
 
 			// Get the 50 best results out of Xapian
-			Xapian::MSet matches = enq.get_mset(0, 50);
+			Xapian::MSet matches = enq.get_mset();
 			for (Xapian::MSetIterator i = matches.begin(); i != matches.end(); ++i)
 			{
 				// Filter out results that apt doesn't know
@@ -190,6 +201,7 @@ bool AptFrontPackageDB::search(std::set<string>& result, const QStringList& incl
 			*/
 		} 
 		else 
+#endif
 		{
 			for ( Apt::record_iterator it = packages.recordBegin(); it != packages.recordEnd(); ++it )
 			{
@@ -261,6 +273,3 @@ bool AptFrontPackageDB::search(std::set<string>& result, const QStringList& incl
 
 }
 
-#undef emit
-//#include <ept/cache/apt/index.tcc>
-//#include <ept/cache/apt/state.tcc>
