@@ -28,6 +28,8 @@
 #include "installedversionplugin.h"
 #include "availableversionplugin.h"
 
+#include "aptsettingswidget.h"
+
 #include <helpers.h>
 
 
@@ -40,7 +42,7 @@ extern "C"
 	
 	NPlugin::PluginInformation get_pluginInformation()
 	{
-		return NPlugin::PluginInformation("aptplugin", "2.3", "Benjamin Mesing");
+		return NPlugin::PluginInformation("aptplugin", "2.4", "Benjamin Mesing");
 	} 
 }
 
@@ -70,7 +72,6 @@ AptPluginContainer::AptPluginContainer( )
 	_pAptFrontPackageDB = 0;
 }
 
- 
 AptPluginContainer::~AptPluginContainer( )
 {
 	delete pluginFactory();
@@ -108,6 +109,46 @@ bool AptPluginContainer::init(IProvider* pProvider)
 	return true;
 }
 
+QWidget* AptPluginContainer::getSettingsWidget(QWidget* pParent)
+{
+	_pSettingsWidget = new AptSettingsWidget(pParent);
+	_pSettingsWidget->setInstallationTool(_pAptActionPlugin->installationTool());
+ 	return _pSettingsWidget;
+}
+
+void AptPluginContainer::applySettings()
+{
+	_pAptActionPlugin->setInstallationTool(_pSettingsWidget->installationTool());
+}
+
+
+
+/////////////////////////////////////////////////////
+// BasePluginContainer Interface
+/////////////////////////////////////////////////////
+
+
+QDomElement AptPluginContainer::loadContainerSettings(const QDomElement source)
+{
+	if (source.tagName() != "ContainerSettings")
+		return source;
+	float settingsVersion;
+	NXml::getAttribute(source, settingsVersion, "settingsVersion", 0.0f);
+	int tool;
+	NXml::getAttribute(source, tool, "installationTool", (int) 0);
+	_pAptActionPlugin->setInstallationTool((InstallationTool) tool);
+	return NXml::getNextElement(source);
+}
+
+void AptPluginContainer::saveContainerSettings(NXml::XmlData& outData, QDomElement parent) const
+{
+	QDomElement containerElement = outData.addElement(parent, "ContainerSettings");
+	outData.addAttribute(containerElement, 0.1f, "settingsVersion");
+	outData.addAttribute(containerElement, _pAptActionPlugin->installationTool(), "installationTool");
+}
+
+
+
 
 /////////////////////////////////////////////////////
 // IAptMediator Interface
@@ -132,22 +173,17 @@ void AptPluginContainer::onAptUpdate()
 	_pCommand = fac.getRunCommand("AptUpdateProcess");
 	connect(_pCommand, SIGNAL(quit()), SLOT(onAptUpdateFinished()) );
 	
-	// BEGIN Workaround for debtags setting bad umask
-	QString shell = "/bin/sh";
-	QString arg1 = "-c";
+ 	QString shell = "/bin/sh";
+ 	QString arg1 = "-c";
 	// this is really ugly, I need to protect this argument, so it is not interpreted
 	// as multiple arguments
-	QString arg2 = "'/usr/bin/apt-get update ; echo Updating debtags index ; umask 022 ; /usr/bin/debtags --reindex update'";
-	_pCommand->addArgument(shell);
-	_pCommand->addArgument(arg1);
+	// first apt-get update is run and then the debtags index is updated, since the
+	// apt database also contains information relevant for the debtags database
+	QString arg2 = "'echo Updateing apt database && /usr/bin/apt-get update && echo Updateing debtags index && /usr/bin/debtags --local update'";
+ 	_pCommand->addArgument(shell);
+ 	_pCommand->addArgument(arg1);
 	_pCommand->addArgument(arg2);
-	// END Workaround for debtags setting bad umask
-
-// Those lines could be used, if debtags update would set the umask all right
-// 	QString command = "/usr/bin/apt-get";
-// 	QString arg1 = "update";
-// 	_pCommand->addArgument(command);
-// 	_pCommand->addArgument(arg1);
+	_pCommand->setTitle("Updateing apt database");
 
 	try 
 	{
@@ -218,9 +254,7 @@ void TestApp::update() {
 
 void AptPluginContainer::onReloadDb()
 {
-	NUtil::ProgressDisplayDlg dlg(provider()->mainWindow(), "PluginProgressDlg", true);
-	dlg.show();
-	_pAptFrontPackageDB->reloadPackageInformation(&dlg);
+	_pAptFrontPackageDB->reloadPackageInformation(0);
 }
 
 }	// namespace NPlugin
