@@ -23,7 +23,7 @@ AptSearchPluginShortInputWidget::~AptSearchPluginShortInputWidget()
 {
 }
 
-void AptSearchPluginShortInputWidget::setClearButton( QPushButton * pButton, int index )
+void AptSearchPluginShortInputWidget::setClearButton( QPushButton * pButton, int)
 {
 	delete(_pClearButton);
 	_pClearButton = pButton;
