@@ -15,8 +15,6 @@
 
 #include <qregexp.h>
 #include <qstringlist.h>
-//Added by qt3to4:
-#include <Q3CString>
 
 
 #include "package.h"
@@ -128,7 +126,7 @@ void Package::parseInformation(const QStringList& lines)
 	for (QStringList::const_iterator it=lines.begin(); it!=lines.end(); ++it)
 	{
 		QString line = (*it);
-		int col = line.find(':');
+		int col = line.indexOf(':');
 		QString key = line.left(col);
 		if (key[0] == ' ') 	// if this is simply a line in another section (the description)
 			col = -1;
