@@ -69,9 +69,9 @@ public:
 	//@{
 	virtual void init(IProvider* pProvider);
 	/// @todo not yet implemented
-	virtual void setEnabled(bool enabled)	{};
+	virtual void setEnabled(bool)	{};
 	/// @todo not yet implemented
-	virtual void setVisible(bool visible)	{};
+	virtual void setVisible(bool)	{};
 	virtual QString name() const { return PLUGIN_NAME; }
 	virtual QString title() const { return _title; };
 	virtual QString briefDescription() const { return _briefDescription; };
