@@ -15,21 +15,20 @@
 
 #include <string>
 
-#include "aggregator.h"
 #include <ept/debtags/tag.h>
-/*
-#include <ept/cache/apt/packages.h>
-#include <ept/cache/package.h>
-#include <ept/cache/relation.h>
-#include <ept/cache/tag.h>
-#include <ept/cache/debtags/vocabulary.h>
-*/
-
-#include "eptinstance.h"
-
+#include <ept/apt/apt.h>
 
 using namespace std;
 
+namespace ept {
+	namespace debtags {
+		class Debtags;
+		class Vocabulary;
+	}
+	namespace apt {
+		class Apt;
+	}
+}
 
 namespace NUtil
 {
@@ -43,15 +42,15 @@ typedef ept::debtags::Vocabulary Vocabulary;
 /** Returns the names of all the packages from <em>packages</em>. */
 inline std::set<string> packagesToStrings(const set<Package>& packages)
 {
-	return packages;
 	/*
 	std::set<string> result;
 	for (set<Package>::const_iterator it = packages.begin(); it != packages.end(); ++it)
 	{
-		result.insert(it->name());
+		result.insert(*it);
 	}
 	return result;
 	*/
+	return packages;
 }
 
 
@@ -69,26 +68,21 @@ inline std::set<string> tagsToStrings(const set<Tag>& tags)
 	return result;
 }
 
-/** Collects the tags from the global vocabulary (accessible through EptInstance)
+/** Collects the tags from the given vocabulary 
   * which match the given names.
   *
   * ?Tag names must be given in the form facet::tagname? (verify this)
   */
-inline std::set<Tag> stringsToTags(const set<string>& tags)
-{
-	std::set<Tag> result;
-	const Vocabulary& tagsComponent = EptInstance::aggregator()->vocabulary();
-	for (set<string>::const_iterator it = tags.begin(); it != tags.end(); ++it)
-	{
-		result.insert(tagsComponent.tagByName(*it));
-	}
-	return result;
-}
+std::set<Tag> stringsToTags(const set<string>& tags, const Vocabulary& vocabulary);
 
-/** Returns the entity::Package with the given name. */
-inline Package getPackageByName(const string package)
+/** Returns the entity::Package with the given name.
+  *
+  * @param string the name of the target package
+  * @param apt a reference to the apt-object
+   */
+inline Package getPackageByName(const string& package, const ept::apt::Apt& apt)
 {
-	return EptInstance::aggregator()->apt().validate(package);
+	return apt.validate(package);
 }
 
 
