@@ -1,7 +1,8 @@
 #ifndef __DEBTAGSPLUGIN_H_2004_06_21
 #define __DEBTAGSPLUGIN_H_2004_06_21
 
-#include <qstring.h>
+#include <QString>
+
 #include <string>
 
 #include <searchplugin.h>
@@ -11,15 +12,19 @@
 
 #include "tagchooserwidget.h"
 
-class Q3ListBoxItem;
+class QAbstractItemView;
 class QPoint;
 
-class ChoosenTagsDisplay;
 namespace NWidgets 
 {
 	class SelectionInputAndDisplay;
 }
 
+namespace NTagModel
+{
+	class VocabularyModel;
+}
+
 using namespace std;
 
 namespace NPlugin
@@ -34,16 +39,15 @@ class DebtagsPlugin : public SearchPlugin, public InformationPlugin
 	Q_OBJECT
 
 	TagChooserWidget* _pChooserWidget;
-	ChoosenTagsDisplay* _pTagsDisplay;
+	
+	NWidgets::SelectionInputAndDisplay* _pTagSelection;
+	
 	/** @brief This holds a link to the manager which manages the plugin.
 	  *
 	  * Acquaintance relation */
-
 	IProvider* _pProvider;
 	/** This manages the include widgets (but not the labels belonging to them. */
-	NWidgets::SelectionInputAndDisplay* _pIncludeSelection;
-	/** This manages the exclude widgets (but not the labels belonging to them. */
-	NWidgets::SelectionInputAndDisplay* _pExcludeSelection;
+// 	NWidgets::SelectionInputAndDisplay* _pIncludeSelection;
 	/** The container which holds this plugin. */
 	const DebtagsPluginContainer& _container;
 	/** Holds if the search is currently inactive. */
@@ -68,9 +72,9 @@ public:
 	  * It does not load the debtags vocabulary if _pColl or _pPackageCollection are 0.*/
 	virtual void init(IProvider* pProvider);
 	/// @todo not yet implemented
-	virtual void setEnabled(bool enabled)	{};
+	virtual void setEnabled(bool)	{};
 	/// @todo not yet implemented
-	virtual void setVisible(bool visible)	{};
+	virtual void setVisible(bool)	{};
 	virtual QString name() const { return PLUGIN_NAME; }
 	virtual QString title() const;
 	virtual QString briefDescription() const;
@@ -84,7 +88,7 @@ public:
 	//@{
 	virtual uint searchPriority() const { return 5; };
 	/** @brief Returns a widget where you can select the debtags you want to in- and exclude. */
-	virtual QWidget* inputWidget() const	{ return _pChooserWidget; };
+	virtual QWidget* inputWidget() const;	
 	/** @brief Returns &quot;Debtags&quot;.  */
 	virtual QString inputWidgetTitle() const	{ return "Debtags"; };
 	virtual QWidget* shortInputAndFeedbackWidget() const;
@@ -92,7 +96,7 @@ public:
 	virtual bool usesFilterTechnique() const	{ return false; };
 	virtual const std::set<string>& searchResult() const;
 	/** This plugin does not use the filter technique. */
-	virtual bool filterPackage(const string& package) const	{ return true; };
+	virtual bool filterPackage(const string&) const	{ return true; };
 	virtual bool isInactive() const	{ return _isInactive; };
 	//@}
 	
@@ -107,7 +111,7 @@ public:
 	/** This plugin does not offer a separate information widget. */
 	virtual QString informationWidgetTitle() const	{ return _emptyString; };
 	/** This plugin does not offer a separate information widget. */
-	virtual void updateInformationWidget(const string& package) {};
+	virtual void updateInformationWidget(const string&) {};
 	/** This plugin does not offer a separate information widget. */
 	virtual void clearInformationWidget() {};
 	/** This plugin offers an information text. */
@@ -130,6 +134,13 @@ protected slots:
 	/** @brief This enables/ disables the visible widgets. */
 	void setWidgetsEnabled(bool enabled);
 
+	/** @brief Called whenever the selection of tags was changed. 
+	  *
+	  * If no tags are selected any more, the widget displaying the selected 
+	  * tags will be hidden.
+	  */
+	void onTagSelectionChanged();
+
 	/** @brief This shows or hides the exclude display elements.
 	  *
 	  * @param display decides if to show (true) or hide (false) the elements. */
@@ -138,6 +149,9 @@ protected slots:
 	  *
 	  * @param display decides if to show (true) or hide (false) the elements. */
 //	void showExcludeInput(bool display);
+protected:
+	/** @brief Returns a pointer to the VocabularyModel instance used. */
+	NTagModel::VocabularyModel* vocabularyModel();
 private:
 
 	/** @brief This creates a search expression which can be used as input for an ExpressionFiler.
