@@ -10,6 +10,7 @@
 
 #include <tagcoll/utils/set.h>
 //#include <ept/cache/debtags/tagmap.h>
+#include <ept/debtags/debtags.h>
 
 // NUtil
 #include <helpers.h>
@@ -78,9 +79,9 @@ void RelatedPlugin::init(IProvider* pProvider)
 	_pRelatedInput = new RelatedInput(_pMainWindow, "RelatedInput");
 	const set<string>& packages = pProvider->packages();
 	for (set<string>::const_iterator it = packages.begin(); it != packages.end(); ++it)
-		_pRelatedInput->_pPackageInput->insertItem(toQString(*it));
+		_pRelatedInput->_pPackageInput->addItem(toQString(*it));
 	_pRelatedInput->_pPackageInput->setMinimumWidth(100);
-	_pRelatedInput->_pPackageInput->setCurrentText("");
+	_pRelatedInput->_pPackageInput->setEditText("");
 	connect(_pRelatedInput->_pPackageInput, SIGNAL(activated(const QString&)), SLOT(evaluateSearch()));
 	connect(_pRelatedInput->_pClearButton, SIGNAL(clicked()), SLOT(onClearSearch()));
 	
@@ -123,7 +124,7 @@ QWidget* RelatedPlugin::shortInputAndFeedbackWidget() const
 
 void RelatedPlugin::clearSearch()
 {
-	_pRelatedInput->_pPackageInput->setCurrentText("");
+	_pRelatedInput->_pPackageInput->setEditText("");
 }
 
 const std::set<string>& RelatedPlugin::searchResult() const
@@ -140,7 +141,7 @@ bool RelatedPlugin::offersScore() const
 	if (isInactive())
 		return false;
  	string package = toString(_pRelatedInput->_pPackageInput->currentText());
-	return !_container.collection()->getTagsOfItem(NUtil::getPackageByName(package)).empty();
+	return !_pProvider->debtags().getTagsOfItem(NUtil::getPackageByName(package, _pProvider->apt())).empty();
 }
 
 map<string, float> RelatedPlugin::getScore(const set<string>& packages) const
@@ -150,10 +151,10 @@ map<string, float> RelatedPlugin::getScore(const set<string>& packages) const
 	assert(!isInactive());
  	string package = toString(_pRelatedInput->_pPackageInput->currentText());
 	int maxdist = _pRelatedInput->_pMaximumDistanceInput->value();
-	std::set<Tag> ts = _container.collection()->getTagsOfItem(NUtil::getPackageByName(package));
+	std::set<Tag> ts = _pProvider->debtags().getTagsOfItem(NUtil::getPackageByName(package, _pProvider->apt()));
 	for (set<string>::const_iterator it = packages.begin(); it != packages.end(); ++it)
 	{
-		int dist = tagcoll::utils::set_distance(ts,  _container.collection()->getTagsOfItem(NUtil::getPackageByName(*it)));
+		int dist = tagcoll::utils::set_distance(ts,  _pProvider->debtags().getTagsOfItem(NUtil::getPackageByName(*it, _pProvider->apt())));
 		result[*it] = float(maxdist - dist + 1) / (maxdist+1);
 	}
 	return result;
@@ -184,8 +185,8 @@ void RelatedPlugin::evaluateSearch()
 		{
 			int maxdist = _pRelatedInput->_pMaximumDistanceInput->value();
 			
-			Package packageEntity = NUtil::getPackageByName(package);
-			std::set<Tag> tags = _container.collection()->getTagsOfItem(packageEntity);
+			Package packageEntity = NUtil::getPackageByName(package, _pProvider->apt());
+			std::set<Tag> tags = _pProvider->debtags().getTagsOfItem(packageEntity);
 			std::set<Package> result = _container.collection()->getRelatedItems(tags, maxdist);
 			for (std::set<Package>::const_iterator it = result.begin(); it != result.end(); ++it)
 			{
