@@ -13,6 +13,11 @@
 #include <scoreplugin.h>
 #include <debtagsplugincontainer.h>
 
+namespace ept {
+namespace debtags {
+class Tag;
+}
+}
 
 class QMainWindow;
 
@@ -50,9 +55,9 @@ public:
 	//@{
 	virtual void init(IProvider* pProvider);
 	/// @todo not yet implemented
-	virtual void setEnabled(bool enabled)	{};
+	virtual void setEnabled(bool)	{};
 	/// @todo not yet implemented
-	virtual void setVisible(bool visible)	{};
+	virtual void setVisible(bool)	{};
 	virtual QString name() const { return PLUGIN_NAME; }
 	virtual QString title() const;
 	virtual QString briefDescription() const;
@@ -74,7 +79,7 @@ public:
 	virtual bool usesFilterTechnique() const	{ return false; };
 	virtual const std::set<string>& searchResult() const;
 	/** This plugin does not use the filter technique. */
-	virtual bool filterPackage(const string& package) const	{ return true; };
+	virtual bool filterPackage(const string&) const	{ return true; };
 	virtual bool isInactive() const	{ return _isInactive; };
 	//@}
 	
