@@ -113,6 +113,10 @@ UnselectedTagsView::UnselectedTagsView(const NPlugin::DebtagsPluginContainer* pC
  		(*it)->setSourceModel(*oldIt);
  		oldIt = it;
  	}
+ 	setToolTip(tr("select a tag by double-clicking"));
+ 	setWhatsThis(tr("This list shows the tags that can be searched for. "
+ 		"The tags are organised in a tree beneath their facets (groups of tags). "
+ 		"To search for packages with a tag, double-click the tag. Multiple tags can be selected like this. Facets cannot be selected."));
 }
 
 
