@@ -15,7 +15,11 @@ class FilenameSearchInput;
 class FilenameFeedbackWidget;
 class QWidget;
 class QTimer;
-class QProcess;
+
+namespace NApplication
+{
+	class RunCommandForOutput;
+}
 
 using namespace std;
 
@@ -40,9 +44,9 @@ public:
 	virtual uint priority() const { return 7; };
 	virtual void init(IProvider* pProvider);
 	/// @todo not yet implemented
-	virtual void setEnabled(bool enabled)	{};
+	virtual void setEnabled(bool)	{};
 	/// @todo not yet implemented
-	virtual void setVisible(bool visible)	{};
+	virtual void setVisible(bool)	{};
 	virtual QString name() const { return PLUGIN_NAME; }
 	/** @returns &quot;FilenamePlugin&quot; */
 	virtual QString title() const;
@@ -79,7 +83,7 @@ public:
 	virtual void clearSearch();
 	virtual bool usesFilterTechnique() const { return false; };
 	virtual const std::set<string>& searchResult() const	{ return _searchResult; };
-	virtual bool filterPackage(const string& package) const	{ return true; };
+	virtual bool filterPackage(const string&) const	{ return true; };
 	virtual bool isInactive() const;
 	//@}
 protected:
@@ -119,12 +123,8 @@ private slots:
 	void onInputTextChanged(const QString&);
 	/** Called when the search process has exited. */
 	void onSearchProcessExited();
-	/** If the filesearch has stdout ready. */
-	void onStdoutFromFilesearch();
 	/** Called when the search process has exited. */
 	void onFilelistProcessExited();
-	/** If the file list has stdout ready. */
-	void onStdoutFromFilelist();
 	/** Called whenever the user clicked "show" in the view. */
 	void onShowRequested();
 private:
@@ -133,7 +133,7 @@ private:
 	/** Process currently executed, make sure to get the _processMutex if you want to use it.
 	  *
 	  * 0 if no process is currently running. */
-	QProcess* _pProcess;
+	NApplication::RunCommandForOutput* _pProcess;
 	/** @brief This checks if the given entry is for the handed package and 
 	  * prepares the entry for output.
 	  * 
