@@ -62,6 +62,11 @@ public:
 	/** @returns true if the process exited successful, i.e. was not aborted and returned an
 	  * exit state of 0. */
 	virtual bool processExitedSuccessful() const=0;
+	/** @brief Sets the title of the window displaying the command to be executed. 
+	  *
+	  * By default the title is the command to be executed with all its arguments.
+	  */
+	virtual void setTitle(const QString& title)=0;
 signals:
 	/** @brief Emitted, when the command finished. */
 	void processExited();
