@@ -70,7 +70,10 @@ bool RunCommandInXterm::start(bool root)
 
 	QStringList arguments;
 	arguments.push_back("-T");
-	arguments.push_back(argumentString);
+	if (_title.isNull())
+		arguments.push_back(argumentString);
+	else
+		arguments.push_back(_title);
 	arguments.push_back("-e");
 	// execute using the shell
 	arguments.push_back("sh");
@@ -123,4 +126,9 @@ void RunCommandInXterm::onProcessExited()
 	emit quit();
 }
 
+void RunCommandInXterm::setTitle(const QString& title)
+{
+	_title = title;
+}
+
 };
