@@ -36,6 +36,8 @@ class RunCommandInXterm : public RunCommand
 	QStringList _arguments;
 	/** The process currently executed. Is 0 if no process is currently executed.  */
 	QProcess* _pProcess;
+	/** @brief The title of the window where the output is shown. */
+	QString _title;
 private slots:
 	void onProcessExited();
 protected:
@@ -54,6 +56,7 @@ public:
 	virtual bool startAsRoot();
 	/** @brief This returns always true as I do not see a way to get hold of the exit status using an xterm. */
 	virtual bool processExitedSuccessful() const	{ return true; };
+	virtual void setTitle(const QString& title);
 };
 
 };	// namespace NApplication
